@@ -2,7 +2,7 @@ from typing import Any, Optional
 
 import aiohttp
 
-from .errors import APIError
+from .errors import APIError, WordNotFound
 
 
 class HTTPClient:
@@ -14,9 +14,12 @@ class HTTPClient:
 
 
     async def get(self, url: str, **kwargs) -> Any:
-        async with self.session.get(url, **kwargs) as res:
+        async with self.session.get(url, timeout=aiohttp.ClientTimeout(60), **kwargs) as res:
             if not 300 >= res.status >= 200:
-                raise APIError(f"{res.status}: Request was fine but there was an error")
+                if res.status == 404:
+                    raise WordNotFound("Sorry pal, we couldn't find definitions for the word you were looking for.")
+                else:
+                    raise APIError(res.status, await res.text())
 
             try:
                 data = await res.json()
@@ -28,4 +31,4 @@ class HTTPClient:
 
     async def close(self) -> None:
         if self.session:
-            self.session.close()
+            await self.session.close()
